import { ParsedIniData } from "@smithy/types";
/**
 * Returns the config data from parsed ini data.
 * * Returns data for `default`
 * * Returns profile name without prefix.
 * * Returns non-profiles as is.
 */
export declare const getConfigData: (data: ParsedIniData) => ParsedIniData;
