import { ParsedIniData as __ParsedIniData, Profile as __Profile, SharedConfigFiles as __SharedConfigFiles } from "@smithy/types";
/**
 * @deprecated Use Profile from "@smithy/types" instead
 */
export type Profile = __Profile;
/**
 * @deprecated Use ParsedIniData from "@smithy/types" instead
 */
export type ParsedIniData = __ParsedIniData;
/**
 * @deprecated Use SharedConfigFiles from "@smithy/types" instead
 */
export type SharedConfigFiles = __SharedConfigFiles;
