import { ParsedIniData } from "@smithy/types";
/**
 * Returns the sso-session data from parsed ini data by reading
 * ssoSessionName after sso-session prefix including/excluding quotes
 */
export declare const getSsoSessionData: (data: ParsedIniData) => ParsedIniData;
